\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{ierp}[2019/07/23 IERP LaTeX Class]

\newcommand{\headlinecolor}{\normalcolor}

\DeclareOption*{\InputIfFileExists{\CurrentOption.min}{}{%
\PassOptionsToClass{\CurrentOption}{article}}}
\ProcessOptions \relax
\LoadClass{article}
\RequirePackage{xcolor}
\RequirePackage{lastpage}
\definecolor{lightblue}{HTML}{0067A5}
\renewcommand{\headlinecolor}{\color{lightblue}}
\RequirePackage{graphicx}
\RequirePackage{tikz}
\newcommand{\papernumber}[1]{\def\@papernumber{#1}}
\newcommand{\papernumberh}[1]{\def\@papernumberh{#1}}
\newcommand{\series}[1]{\def\@series{#1}}
\newcommand{\affiliation}[1]{\def\@affiliation{#1}}
\newcommand{\email}[1]{\def\@email{#1}}


%Changed by TKlarl
\RequirePackage{caption}
\renewcommand{\figurename}{Table}
\captionsetup[table]{labelfont={color=lightblue}}
\renewcommand{\figurename}{Figure}
\captionsetup[figure]{labelfont={color=lightblue}}
%\RequirePackage{hyperref}
%\hypersetup{colorlinks=true,citecolor=blue}

%End of Changes

\renewcommand{\maketitle}{%
\tikz[remember picture,overlay] \node[inner sep=0pt] at (current page.center){\includegraphics[width=\paperwidth,height=\paperheight]{image3.jpeg}};\par
        {\vspace*{2cm}
        {\fontsize{36}{36}\fontfamily{phv}%
        \selectfont\noindent
        \@papernumber}
        \bigskip
        {\fontsize{15}{15}\fontfamily{phv}%
        \selectfont\noindent
        Bremen Papers on Economics \& Innovation \par}
        \bigskip
        \fontsize{24}{30}\fontfamily{phv}%
        \selectfont\headlinecolor\noindent
        \@title \par
        \bigskip\bigskip
        \normalcolor
        \noindent
        \@author\par
        \vspace*{1cm}
        \headlinecolor
        % \hrule
        \par\vspace*{1cm}
        \normalcolor\normalsize\noindent\@date\par\vspace*{0.5cm}
        }
}
 
  
\renewcommand{\section}{%
    \@startsection
    {section}{1}{0pt}
    {-3.5ex \@plus -1ex \@minus -.2ex}%
    {2.3ex \@plus.2ex}%
    {\large\fontfamily{phv}\selectfont\bfseries\headlinecolor}%
}

\renewcommand{\subsection}{%
    \@startsection
    {subsection}{1}{0pt}
    {-3.5ex \@plus -1ex \@minus -.2ex}%
    {2.3ex \@plus.2ex}%
    {\large\fontfamily{phv}\selectfont\bfseries\headlinecolor}%
}

\renewcommand{\subsubsection}{%
    \@startsection
    {subsubsection}{1}{0pt}
    {-3.5ex \@plus -1ex \@minus -.2ex}%
    {2.3ex \@plus.2ex}%
    {\large\fontfamily{phv}\selectfont\bfseries\headlinecolor}%
}

\renewcommand{\familydefault}{phv}

% \renewcommand{\normalsize}{\fontsize{9}{10}\selectfont}
\RequirePackage[includehead,paper=a4paper,left=4cm,right=2cm,top=0.5cm,bottom=6cm]{geometry}
\RequirePackage{fancyhdr}


\fancypagestyle{firstpage}{%
\fancyhf{} % clear all six fields
\rhead{\includegraphics[width=2.4cm]{image2.jpg}}
\lfoot{\vspace*{2.5cm}\@affiliation\\
\@email}
\rfoot{\vspace{2.5cm}\includegraphics[width=3.5cm]{image1.jpeg}}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}
}

\fancypagestyle{followingpage}{%
\fancyhf{} % clear all six fields
\rhead{\includegraphics[width=2.4cm]{image2.jpg}}
\chead{  \begin{tikzpicture}[remember picture,overlay]
    \node[] at (-0.45\paperwidth,0.07\paperheight) {\thepage\ / \pageref{LastPage}};
  \end{tikzpicture}}
\lhead{{\fontsize{15}{15}\selectfont\@papernumberh} \@series \\ 
\vspace{\baselineskip} 
\@title}
\renewcommand{\headrulewidth}{0.7pt}
\renewcommand{\footrulewidth}{0pt}
\renewcommand{\headrule}{\hbox to\headwidth{%
  \color{lightblue}\leaders\hrule height \headrulewidth\hfill}}
}

\pagestyle{followingpage}
\AtBeginDocument{\thispagestyle{firstpage}}

